@@ -13,8 +13,8 @@
 #' Extract instantaneous sediment sample particle size distribution information from the HYDAT database
 #'
 #' Provides wrapper to turn the hy_sed_samples_psd table in HYDAT into a tidy data frame of instantaneous sediment sample 
-#' particle size distribution.  \code{station_number} and \code{prov_terr_state_loc} can both be supplied. If both 
-#' are omitted all values from the \code{hy_stations} table are returned. That is a large vector for \code{hy_sed_samples_psd}.
+#' particle size distribution.  `station_number` and `prov_terr_state_loc` can both be supplied. If both 
+#' are omitted all values from the [hy_stations()] table are returned. That is a large vector for `hy_sed_samples_psd`.
 #'
 #' @inheritParams hy_stations
 #' @param start_date Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
@@ -55,7 +55,7 @@ hy_sed_samples_psd <- function(station_number = NULL,
   ## Read in database
   hydat_con <- hy_src(hydat_path)
   if (!dplyr::is.src(hydat_path)) {
-    on.exit(hy_src_disconnect(hydat_con))
+    on.exit(hy_src_disconnect(hydat_con), add = TRUE)
   }
   
   ## Determine which stations we are querying
