@@ -13,12 +13,16 @@
 ## Add "realtime" class
 as.realtime <- function(x) {
   class(x) <- c("realtime", setdiff(class(x), "realtime"))
+  t <- Sys.time()
+  attr(t, "tzone") <- "UTC"
+  attr(x, "query_time") <- t
+
   x
 }
 
 #' @export
 print.realtime <- function(x, ...){
-  cat(paste("  Queried on:", format(Sys.time(), tz = "UTC"), "(UTC)\n"))
+  cat(paste("  Queried on:", attributes(x)$query_time, "(UTC)\n"))
   if(c("Date") %in% names(x) && !all(is.na(x$Date))){
     date_range = paste0(range(as.Date(x$Date), na.rm = TRUE), collapse = " to ")
     cat(paste0("  Date range: ", date_range, " \n"))
